@@ -253,6 +253,7 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     RUN_MANILA_REVERT_TO_SNAPSHOT_TESTS=True
     RUN_MANILA_MOUNT_SNAPSHOT_TESTS=True
     RUN_MANILA_MIGRATION_WITH_PRESERVE_SNAPSHOTS_TESTS=True
+    RUN_MANILA_REPLICATION_TESTS=True
     iniset $TEMPEST_CONFIG share enable_ip_rules_for_protocols 'nfs'
     iniset $TEMPEST_CONFIG share enable_user_rules_for_protocols 'cifs'
     iniset $TEMPEST_CONFIG share enable_cert_rules_for_protocols ''
@@ -266,6 +267,7 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     iniset $TEMPEST_CONFIG share multitenancy_enabled True
     iniset $TEMPEST_CONFIG share create_networks_when_multitenancy_enabled False
     iniset $TEMPEST_CONFIG share multi_backend True
+    iniset $TEMPEST_CONFIG share backend_replication_type 'readable'
 elif [[ "$DRIVER" == "container"* ]]; then
     if [[ "$DRIVER" == "container_with_custom_image" ]]; then
         # TODO(vponomaryov): set scenario tests for run when
@@ -342,10 +344,34 @@ export OS_USER_DOMAIN_NAME=$ADMIN_DOMAIN_NAME
 source $BASE/new/manila/contrib/ci/common.sh
 manila_wait_for_drivers_init $MANILA_CONF
 
+
+TCP_PORTS=(2049 111 32803 892 875 662)
+UDP_PORTS=(111 32769 892 875 662)
+for ipcmd in iptables ip6tables; do
+    # (aovchinnikov): extra rules are needed to allow instances talk to host.
+    sudo $ipcmd -N manila-nfs
+    sudo $ipcmd -I INPUT 1 -j manila-nfs
+    for port in ${TCP_PORTS[*]}; do
+        sudo $ipcmd -A manila-nfs -m tcp -p tcp --dport $port -j ACCEPT
+    done
+    for port in ${UDP_PORTS[*]}; do
+        sudo $ipcmd -A manila-nfs -m udp -p udp --dport $port -j ACCEPT
+    done
+done
+
 source $BASE/new/devstack/openrc admin admin
 public_net_id=$(openstack network list --name $PUBLIC_NETWORK_NAME -f value -c ID )
 iniset $TEMPEST_CONFIG network public_network_id $public_net_id
 
+if [ $(trueorfalse False MANILA_SETUP_IPV6) == True ]; then
+    # Now that all plugins are loaded, setup BGP here
+    public_gateway_ipv6=$(openstack subnet show ipv6-public-subnet -c gateway_ip -f value)
+    neutron bgp-speaker-create --ip-version 6 --local-as 100 bgpspeaker
+    neutron bgp-speaker-network-add bgpspeaker $PUBLIC_NETWORK_NAME
+    neutron bgp-peer-create --peer-ip $public_gateway_ipv6 --remote-as 200 bgppeer
+    neutron bgp-speaker-peer-add bgpspeaker bgppeer
+fi
+
 # Set config to run IPv6 tests according to env var
 iniset $TEMPEST_CONFIG share run_ipv6_tests $RUN_MANILA_IPV6_TESTS
 
