@@ -29,8 +29,8 @@ echo "VOLUME_BACKING_FILE_SIZE=22G" >> $localconf
 echo "CINDER_LVM_TYPE=thin" >> $localconf
 
 # Set DevStack's PYTHON3_VERSION variable if CI scripts specify it
-if ! [[ -z "PYTHON3_VERSION" ]]; then
-echo "PYTHON3_VERSION=$PYTHON3_VERSION" >> $localconf
+if [[ ! -z "$PYTHON3_VERSION" ]]; then
+    echo "PYTHON3_VERSION=$PYTHON3_VERSION" >> $localconf
 fi
 
 # NOTE(mkoderer): switch to keystone v3 by default
@@ -47,8 +47,6 @@ echo "MANILA_SHARE_BACKEND2_NAME=PARIS" >> $localconf
 
 echo "MANILA_INSTALL_TEMPEST_PLUGIN_SYSTEMWIDE=${MANILA_INSTALL_TEMPEST_PLUGIN_SYSTEMWIDE:=True}" >> $localconf
 
-echo "MANILA_ALLOW_NAS_SERVER_PORTS_ON_HOST=${MANILA_ALLOW_NAS_SERVER_PORTS_ON_HOST:=False}" >> $localconf
-
 # === Handle script arguments ===
 # First argument is expected to be a boolean-like value for DHSS.
 DHSS=$1
@@ -111,12 +109,14 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     echo "MANILA_OPTGROUP_alpha_share_backend_name=ALPHA" >> $localconf
     echo "MANILA_OPTGROUP_alpha_network_config_group=membernet" >> $localconf
     echo "MANILA_OPTGROUP_alpha_admin_network_config_group=adminnet" >> $localconf
+    echo "MANILA_OPTGROUP_alpha_replication_domain=DUMMY_DOMAIN_2" >> $localconf
 
     echo "MANILA_OPTGROUP_beta_share_driver=$driver_path" >> $localconf
     echo "MANILA_OPTGROUP_beta_driver_handles_share_servers=True" >> $localconf
     echo "MANILA_OPTGROUP_beta_share_backend_name=BETA" >> $localconf
     echo "MANILA_OPTGROUP_beta_network_config_group=membernet" >> $localconf
     echo "MANILA_OPTGROUP_beta_admin_network_config_group=adminnet" >> $localconf
+    echo "MANILA_OPTGROUP_beta_replication_domain=DUMMY_DOMAIN_2" >> $localconf
 
     echo "MANILA_OPTGROUP_gamma_share_driver=$driver_path" >> $localconf
     echo "MANILA_OPTGROUP_gamma_driver_handles_share_servers=False" >> $localconf
