@@ -213,7 +213,7 @@ function configure_manila {
     # Remove old conf file if exists
     rm -f $MANILA_CONF
 
-    configure_auth_token_middleware $MANILA_CONF manila  $MANILA_AUTH_CACHE_DIR
+    configure_keystone_authtoken_middleware $MANILA_CONF manila
 
     iniset $MANILA_CONF DEFAULT auth_strategy keystone
     iniset $MANILA_CONF DEFAULT debug True
@@ -253,13 +253,13 @@ function configure_manila {
     iniset $MANILA_CONF DEFAULT replica_state_update_interval $MANILA_REPLICA_STATE_UPDATE_INTERVAL
 
     if is_service_enabled neutron; then
-        configure_auth_token_middleware $MANILA_CONF neutron $MANILA_AUTH_CACHE_DIR neutron
+        configure_keystone_authtoken_middleware $MANILA_CONF neutron neutron
     fi
     if is_service_enabled nova; then
-        configure_auth_token_middleware $MANILA_CONF nova $MANILA_AUTH_CACHE_DIR nova
+        configure_keystone_authtoken_middleware $MANILA_CONF nova nova
     fi
     if is_service_enabled cinder; then
-        configure_auth_token_middleware $MANILA_CONF cinder $MANILA_AUTH_CACHE_DIR cinder
+        configure_keystone_authtoken_middleware $MANILA_CONF cinder cinder
     fi
 
     # Note: set up config group does not mean that this backend will be enabled.
@@ -405,10 +405,10 @@ function configure_data_service_generic_driver {
     if [[ $share_driver == $generic_driver ]]; then
         driver_handles_share_servers=$(iniget $MANILA_CONF ${enabled_backends[0]} driver_handles_share_servers)
         if [[ $(trueorfalse False driver_handles_share_servers) == False ]]; then
-            iniset $MANILA_CONF DEFAULT data_node_access_ip $PUBLIC_NETWORK_GATEWAY
+            iniset $MANILA_CONF DEFAULT data_node_access_ips $PUBLIC_NETWORK_GATEWAY
         else
             if ! [[ -z $MANILA_DATA_NODE_IP ]]; then
-                iniset $MANILA_CONF DEFAULT data_node_access_ip $MANILA_DATA_NODE_IP
+                iniset $MANILA_CONF DEFAULT data_node_access_ips $MANILA_DATA_NODE_IP
             fi
         fi
     fi
@@ -658,15 +658,10 @@ function init_manila {
                 cat $STACK_HOME/.ssh/*.pub >> $SSH_USER_HOME/.ssh/authorized_keys
                 # Give ssh user sudo access
                 echo "$MANILA_ZFSONLINUX_SSH_USERNAME ALL=(ALL) NOPASSWD: ALL" | sudo tee -a /etc/sudoers > /dev/null
-                iniset $MANILA_CONF DEFAULT data_node_access_ip $MANILA_ZFSONLINUX_SERVICE_IP
+                iniset $MANILA_CONF DEFAULT data_node_access_ips $MANILA_ZFSONLINUX_SERVICE_IP
             fi
         fi
     fi
-
-    # Create cache dir
-    sudo mkdir -p $MANILA_AUTH_CACHE_DIR
-    sudo chown $STACK_USER $MANILA_AUTH_CACHE_DIR
-    rm -f $MANILA_AUTH_CACHE_DIR/*
 }
 
 # check_nfs_kernel_service_state_ubuntu- Make sure nfsd is running
@@ -721,8 +716,10 @@ function install_manila {
 
     if is_service_enabled m-shr; then
 
-        if [[ ! $(systemctl is-active nfs-ganesha.service) == 'active' ]]; then
-            _install_nfs_and_samba
+        if [[ ! $(systemctl is-active nfs-ganesha.service) == 'active' ]] ; then
+            if [ "$SHARE_DRIVER" != "manila.share.drivers.cephfs.driver.CephFSDriver" ] ; then
+                _install_nfs_and_samba
+            fi
         fi
 
         if [ "$SHARE_DRIVER" == "manila.share.drivers.zfsonlinux.driver.ZFSonLinuxShareDriver" ]; then
@@ -815,7 +812,7 @@ function configure_samba {
             iniset $MANILA_CONF $backend_name driver_handles_share_servers False
             iniset $MANILA_CONF $backend_name lvm_share_export_ips $MANILA_LVM_SHARE_EXPORT_IPS
         done
-        iniset $MANILA_CONF DEFAULT data_node_access_ip $HOST_IP
+        iniset $MANILA_CONF DEFAULT data_node_access_ips $HOST_IP
     fi
 }
 
@@ -835,7 +832,7 @@ function start_manila_api {
 
     if [ $(trueorfalse False MANILA_USE_UWSGI) == True ]; then
         echo "Deploying with UWSGI"
-        run_process m-api "$(which uwsgi) --ini $MANILA_UWSGI_CONF --procname-prefix manila-api"
+        run_process m-api "$MANILA_BIN_DIR/uwsgi --ini $MANILA_UWSGI_CONF --procname-prefix manila-api"
     elif [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
         echo "Deploying with MOD_WSGI"
         install_apache_wsgi
@@ -917,14 +914,6 @@ function install_manila_tempest_plugin {
 # update_tempest - Function used for updating Tempest config if Tempest service enabled
 function update_tempest {
     if is_service_enabled tempest; then
-
-        if [[ "$(trueorfalse False MANILA_SETUP_IPV6)" == "True" ]]; then
-            # The public network was created by us, so set it explicitly in
-            # tempest.conf
-            public_net_id=$(openstack network list --name $PUBLIC_NETWORK_NAME -f value -c ID )
-            iniset $TEMPEST_CONFIG network public_network_id $public_net_id
-        fi
-
         TEMPEST_CONFIG=${TEMPEST_CONFIG:-$TEMPEST_DIR/etc/tempest.conf}
         ADMIN_TENANT_NAME=${ADMIN_TENANT_NAME:-"admin"}
         ADMIN_DOMAIN_NAME=${ADMIN_DOMAIN_NAME:-"Default"}
@@ -1019,33 +1008,6 @@ function install_libraries {
     fi
 }
 
-function allow_host_ports_for_share_mounting {
-
-    if [[ $MANILA_ENABLED_SHARE_PROTOCOLS =~ NFS ]]; then
-        # 111 and 2049 are for rpcbind and NFS
-        # Other ports are for NFSv3 statd, mountd and lockd daemons
-        MANILA_TCP_PORTS=(2049 111 32803 892 875 662)
-        MANILA_UDP_PORTS=(111 32769 892 875 662)
-    fi
-    if [[ $MANILA_ENABLED_SHARE_PROTOCOLS =~ CEPHFS ]]; then
-        # clients need access to the ceph daemons
-        MANILA_TCP_PORTS=(${MANILA_TCP_PORTS[*]} 6789 6800:7300)
-    fi
-
-    if [[ -v MANILA_TCP_PORTS || -v MANILA_UDP_PORTS ]]; then
-        for ipcmd in iptables ip6tables; do
-            sudo $ipcmd -N manila-storage
-            sudo $ipcmd -I INPUT 1 -j manila-storage
-            for port in ${MANILA_TCP_PORTS[*]}; do
-                sudo $ipcmd -A manila-storage -m tcp -p tcp --dport $port -j ACCEPT
-            done
-            for port in ${MANILA_UDP_PORTS[*]}; do
-                sudo $ipcmd -A manila-storage -m udp -p udp --dport $port -j ACCEPT
-            done
-        done
-    fi
-}
-
 function setup_ipv6 {
 
     # This will fail with multiple default routes and is not needed in CI
@@ -1097,7 +1059,14 @@ function setup_ipv6 {
         for backend_name in ${MANILA_ENABLED_BACKENDS//,/ }; do
             iniset $MANILA_CONF $backend_name lvm_share_export_ips $public_gateway_ipv4,$public_gateway_ipv6
         done
-        iniset $MANILA_CONF DEFAULT data_node_access_ip $public_gateway_ipv4
+        iniset $MANILA_CONF DEFAULT data_node_access_ips $public_gateway_ipv4
+    fi
+
+    if [ "$SHARE_DRIVER" == "manila.share.drivers.cephfs.driver.CephFSDriver" ]; then
+        for backend_name in ${MANILA_ENABLED_BACKENDS//,/ }; do
+            iniset $MANILA_CONF $backend_name cephfs_ganesha_export_ips $public_gateway_ipv4,$public_gateway_ipv6
+        done
+        iniset $MANILA_CONF DEFAULT data_node_access_ips $public_gateway_ipv4
     fi
 
     # install Quagga for setting up the host routes dynamically
@@ -1182,14 +1151,6 @@ function setup_ipv6 {
 
 }
 
-function setup_bgp_for_ipv6 {
-    public_gateway_ipv6=$(openstack subnet show ipv6-public-subnet -c gateway_ip -f value)
-    neutron bgp-speaker-create --ip-version 6 --local-as 100 bgpspeaker
-    neutron bgp-speaker-network-add bgpspeaker $PUBLIC_NETWORK_NAME
-    neutron bgp-peer-create --peer-ip $public_gateway_ipv6 --remote-as 200 bgppeer
-    neutron bgp-speaker-peer-add bgpspeaker bgppeer
-}
-
 # Main dispatcher
 if [[ "$1" == "stack" && "$2" == "install" ]]; then
     echo_summary "Installing Manila Client"
@@ -1301,19 +1262,6 @@ elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
 
     echo_summary "Update Tempest config"
     update_tempest
-
-
-    if [[ "$(trueorfalse False MANILA_ALLOW_NAS_SERVER_PORTS_ON_HOST)" == "True" ]]; then
-        echo_summary "Allowing IPv4 and IPv6 access to NAS ports on the host"
-        allow_host_ports_for_share_mounting
-    fi
-
-    if [[ "$(trueorfalse False MANILA_SETUP_IPV6)" == "True" ]]; then
-        # Now that all plugins are loaded, setup BGP
-        echo_summary "Setting up BGP speaker to advertise routes to project networks"
-        setup_bgp_for_ipv6
-    fi
-
 fi
 
 if [[ "$1" == "unstack" ]]; then
