@@ -150,7 +150,7 @@ WINRM_PORTS = (
 )
 
 SERVICE_INSTANCE_SECGROUP_DATA = (
-    CIFS_PORTS + NFS_PORTS + SSH_PORTS + PING_PORTS + WINRM_PORTS)
+    CIFS_PORTS + NFS_PORTS + PING_PORTS + WINRM_PORTS)
 
 ACCESS_LEVEL_RW = 'rw'
 ACCESS_LEVEL_RO = 'ro'
@@ -196,6 +196,7 @@ class ExtraSpecs(object):
     CREATE_SHARE_FROM_SNAPSHOT_SUPPORT = "create_share_from_snapshot_support"
     REVERT_TO_SNAPSHOT_SUPPORT = "revert_to_snapshot_support"
     MOUNT_SNAPSHOT_SUPPORT = "mount_snapshot_support"
+    AVAILABILITY_ZONES = "availability_zones"
 
     # Extra specs containers
     REQUIRED = (
@@ -208,6 +209,7 @@ class ExtraSpecs(object):
         REVERT_TO_SNAPSHOT_SUPPORT,
         REPLICATION_TYPE_SPEC,
         MOUNT_SNAPSHOT_SUPPORT,
+        AVAILABILITY_ZONES,
     )
 
     # NOTE(cknight): Some extra specs are necessary parts of the Manila API and
