@@ -228,6 +228,11 @@ class ShareNetworkNotFound(NotFound):
     message = _("Share network %(share_network_id)s could not be found.")
 
 
+class ShareNetworkSubnetNotFound(NotFound):
+    message = _("Share network subnet %(share_network_subnet_id)s could not be"
+                " found.")
+
+
 class ShareServerNotFound(NotFound):
     message = _("Share server %(share_server_id)s could not be found.")
 
@@ -636,8 +641,8 @@ class ShareGroupTypeSpecsNotFound(NotFound):
 
 
 class ShareTypeInUse(ManilaException):
-    message = _("Share Type %(share_type_id)s deletion is not allowed while "
-                "shares or share group types are associated with the type.")
+    message = _("Share Type %(share_type_id)s deletion is not allowed with "
+                "shares present with the type.")
 
 
 class IPAddressInUse(InUse):
@@ -681,6 +686,10 @@ class ShareTypeCreateFailed(ManilaException):
                 "name %(name)s and specs %(extra_specs)s.")
 
 
+class ShareTypeUpdateFailed(ManilaException):
+    message = _("Cannot update share_type %(id)s.")
+
+
 class ShareGroupTypeCreateFailed(ManilaException):
     message = _("Cannot create share group type with "
                 "name %(name)s and specs %(group_specs)s.")
@@ -751,15 +760,15 @@ class VserverNotSpecified(NetAppException):
     message = _("Vserver not specified.")
 
 
-class EMCVmaxXMLAPIError(Invalid):
+class EMCPowerMaxXMLAPIError(Invalid):
     message = _("%(err)s")
 
 
-class EMCVmaxLockRequiredException(ManilaException):
+class EMCPowerMaxLockRequiredException(ManilaException):
     message = _("Unable to acquire lock(s).")
 
 
-class EMCVmaxInvalidMoverID(ManilaException):
+class EMCPowerMaxInvalidMoverID(ManilaException):
     message = _("Invalid mover or vdm %(id)s.")
 
 
@@ -967,3 +976,13 @@ class LockingFailed(ManilaException):
 # Ganesha library
 class GaneshaException(ManilaException):
     message = _("Unknown NFS-Ganesha library exception.")
+
+
+# Infortrend Storage driver
+class InfortrendCLIException(ShareBackendException):
+    message = _("Infortrend CLI exception: %(err)s "
+                "Return Code: %(rc)s, Output: %(out)s")
+
+
+class InfortrendNASException(ShareBackendException):
+    message = _("Infortrend NAS exception: %(err)s")
