@@ -143,7 +143,7 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
 
         if not ip_lib.device_exists(device_name,
                                     namespace=namespace):
-
+            LOG.info("Device %s does not exist - creating ....", device_name)
             tap_name = self._get_tap_name(device_name)
             self._ovs_add_port(bridge, tap_name, port_id, mac_address)
             ns_dev.link.set_address(mac_address)
@@ -154,7 +154,10 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
                 namespace_obj.add_device_to_namespace(ns_dev)
 
         else:
-            LOG.warning("Device %s already exists.", device_name)
+            LOG.info("Device %s already exists.", device_name)
+            if ns_dev.link.address != mac_address:
+                LOG.warning("Reset mac address to %s", mac_address)
+                ns_dev.link.set_address(mac_address)
         ns_dev.link.set_up()
 
     @device_name_synchronized
