@@ -1,4 +1,4 @@
-# Copyright (c) 2014 EMC Corporation.
+# Copyright (c) 2019 EMC Corporation.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -21,6 +21,7 @@ to specify, which backend plugins to use.
 """
 
 from oslo_config import cfg
+from oslo_log import log
 
 from manila.share import driver
 from manila.share.drivers.dell_emc import plugin_manager as manager
@@ -40,7 +41,7 @@ EMC_NAS_OPTS = [
                 help='Use secure connection to server.'),
     cfg.StrOpt('emc_share_backend',
                ignore_case=True,
-               choices=['isilon', 'vnx', 'unity', 'vmax'],
+               choices=['isilon', 'vnx', 'unity', 'vmax', 'powermax'],
                help='Share backend.'),
     cfg.StrOpt('emc_nas_root_dir',
                help='The root directory where shares will be located.'),
@@ -54,6 +55,8 @@ EMC_NAS_OPTS = [
                     'CAs, which will be used to validate the backend.')
 ]
 
+LOG = log.getLogger(__name__)
+
 CONF = cfg.CONF
 CONF.register_opts(EMC_NAS_OPTS)
 
@@ -72,6 +75,12 @@ class EMCShareDriver(driver.ShareDriver):
         self.backend_name = self.backend_name or 'EMC_NAS_Storage'
         self.plugin_manager = manager.EMCPluginManager(
             namespace='manila.share.drivers.dell_emc.plugins')
+        if self.backend_name == 'vmax':
+            LOG.warning("Configuration option 'emc_share_backend=vmax' will "
+                        "remain a valid option until the V release of "
+                        "OpenStack. After that, only "
+                        "'emc_share_backend=powermax' will be excepted.")
+            self.backend_name = 'powermax'
         self.plugin = self.plugin_manager.load_plugin(
             self.backend_name,
             configuration=self.configuration)
@@ -81,6 +90,16 @@ class EMCShareDriver(driver.ShareDriver):
         if hasattr(self.plugin, 'ipv6_implemented'):
             self.ipv6_implemented = self.plugin.ipv6_implemented
 
+        if hasattr(self.plugin, 'revert_to_snap_support'):
+            self.revert_to_snap_support = self.plugin.revert_to_snap_support
+        else:
+            self.revert_to_snap_support = False
+
+        if hasattr(self.plugin, 'shrink_share_support'):
+            self.shrink_share_support = self.plugin.shrink_share_support
+        else:
+            self.shrink_share_support = False
+
     def create_share(self, context, share, share_server=None):
         """Is called to create share."""
         location = self.plugin.create_share(context, share, share_server)
@@ -99,6 +118,13 @@ class EMCShareDriver(driver.ShareDriver):
         """Is called to extend share."""
         self.plugin.extend_share(share, new_size, share_server)
 
+    def shrink_share(self, share, new_size, share_server=None):
+        """Is called to shrink share."""
+        if self.shrink_share_support:
+            self.plugin.shrink_share(share, new_size, share_server)
+        else:
+            raise NotImplementedError()
+
     def create_snapshot(self, context, snapshot, share_server=None):
         """Is called to create snapshot."""
         self.plugin.create_snapshot(context, snapshot, share_server)
@@ -147,7 +173,8 @@ class EMCShareDriver(driver.ShareDriver):
             vendor_name='Dell EMC',
             storage_protocol='NFS_CIFS',
             snapshot_support=True,
-            create_share_from_snapshot_support=True)
+            create_share_from_snapshot_support=True,
+            revert_to_snapshot_support=self.revert_to_snap_support)
         self.plugin.update_share_stats(data)
         super(EMCShareDriver, self)._update_share_stats(data)
 
@@ -168,3 +195,13 @@ class EMCShareDriver(driver.ShareDriver):
             return [4, 6]
         else:
             return [4]
+
+    def revert_to_snapshot(self, context, snapshot, share_access_rules,
+                           snapshot_access_rules, share_server=None):
+        if self.revert_to_snap_support:
+            return self.plugin.revert_to_snapshot(context, snapshot,
+                                                  share_access_rules,
+                                                  snapshot_access_rules,
+                                                  share_server)
+        else:
+            raise NotImplementedError()
