@@ -74,6 +74,12 @@ _MANILA_TO_INFINIDAT_ACCESS_LEVEL = {
     constants.ACCESS_LEVEL_RO: 'RO',
 }
 
+# Max retries for the REST API client in case of a failure:
+_API_MAX_RETRIES = 5
+# Identifier used as the REST API User-Agent string:
+_INFINIDAT_MANILA_IDENTIFIER = (
+    "manila/%s" % version.version_info.release_string())
+
 
 def infinisdk_to_manila_exceptions(func):
     @functools.wraps(func)
@@ -98,6 +104,16 @@ class InfiniboxShareDriver(driver.ShareDriver):
         self.configuration.append_config_values(infinidat_auth_opts)
         self.configuration.append_config_values(infinidat_general_opts)
 
+    def _setup_and_get_system_object(self, management_address, auth):
+        system = infinisdk.InfiniBox(management_address, auth=auth)
+        system.api.add_auto_retry(
+            lambda e: isinstance(
+                e, infinisdk.core.exceptions.APITransportFailure) and
+            "Interrupted system call" in e.error_desc, _API_MAX_RETRIES)
+        system.api.set_source_identifier(_INFINIDAT_MANILA_IDENTIFIER)
+        system.login()
+        return system
+
     def do_setup(self, context):
         """Driver initialization"""
         if infinisdk is None:
@@ -110,7 +126,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
             self._safe_get_from_config_or_fail('infinibox_password'))
         auth = (infinibox_login, infinibox_password)
 
-        self.management_address = (
+        management_address = (
             self._safe_get_from_config_or_fail('infinibox_hostname'))
 
         self._pool_name = (
@@ -120,8 +136,8 @@ class InfiniboxShareDriver(driver.ShareDriver):
             self._safe_get_from_config_or_fail(
                 'infinidat_nas_network_space_name'))
 
-        self._system = infinisdk.InfiniBox(self.management_address, auth=auth)
-        self._system.login()
+        self._system = (
+            self._setup_and_get_system_object(management_address, auth))
 
         backend_name = self.configuration.safe_get('share_backend_name')
         self._backend_name = backend_name or self.__class__.__name__
@@ -158,6 +174,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
         super(InfiniboxShareDriver, self)._update_share_stats(data)
 
     def _get_available_capacity(self):
+        # pylint: disable=no-member
         pool = self._get_infinidat_pool()
         free_capacity_bytes = (pool.get_free_physical_capacity() /
                                capacity.byte)
@@ -166,6 +183,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
         provisioned_capacity_gb = (
             (pool.get_virtual_capacity() - pool.get_free_virtual_capacity()) /
             capacity.GB)
+        # pylint: enable=no-member
         return (free_capacity_bytes, physical_capacity_bytes,
                 provisioned_capacity_gb)
 
@@ -200,10 +218,11 @@ class InfiniboxShareDriver(driver.ShareDriver):
         return 'openstack-snap-%s' % manila_snapshot['id']
 
     def _set_manila_object_metadata(self, infinidat_object, manila_object):
-        data = dict(system="openstack",
-                    openstack_version=version.version_info.release_string(),
-                    manila_id=manila_object['id'],
-                    manila_name=manila_object['name'])
+        data = {"system": "openstack",
+                "openstack_version": version.version_info.release_string(),
+                "manila_id": manila_object['id'],
+                "manila_name": manila_object['name'],
+                "host.created_by": _INFINIDAT_MANILA_IDENTIFIER}
         infinidat_object.set_metadata_from_dict(data)
 
     @infinisdk_to_manila_exceptions
@@ -220,23 +239,31 @@ class InfiniboxShareDriver(driver.ShareDriver):
         network_space = self._system.network_spaces.safe_get(
             name=self._network_space_name)
         if network_space is None:
-            msg = _('Network space "%s" not found') % self._network_space_name
+            msg = _('INFINIDAT InfiniBox NAS network space "%s" '
+                    'not found') % self._network_space_name
             LOG.error(msg)
             raise exception.ShareBackendException(msg=msg)
         network_space_ips = network_space.get_ips()
         if not network_space_ips:
-            msg = _('INFINIDAT InfiniBox NAS Network Space "%s" has no IPs '
-                    'defined') % self._network_space_name
+            msg = _('INFINIDAT InfiniBox NAS network space "%s" has no IP '
+                    'addresses defined') % self._network_space_name
             LOG.error(msg)
             raise exception.ShareBackendException(msg=msg)
-        return [ip_munch.ip_address for ip_munch in network_space_ips]
+        ip_addresses = (
+            [ip_munch.ip_address for ip_munch in network_space_ips if
+             ip_munch.enabled])
+        if not ip_addresses:
+            msg = _('INFINIDAT InfiniBox NAS network space "%s" has no '
+                    'enabled IP addresses') % self._network_space_name
+            LOG.error(msg)
+            raise exception.ShareBackendException(msg=msg)
+        return ip_addresses
 
-    @infinisdk_to_manila_exceptions
-    def _get_full_nfs_export_path(self, export_path):
+    def _get_full_nfs_export_paths(self, export_path):
         network_space_ips = self._get_infinidat_nas_network_space_ips()
-        return '{network_space_ip}:{export_path}'.format(
-            network_space_ip=network_space_ips[0],
-            export_path=export_path)
+        return ['{network_space_ip}:{export_path}'.format(
+            network_space_ip=network_space_ip,
+            export_path=export_path) for network_space_ip in network_space_ips]
 
     @infinisdk_to_manila_exceptions
     def _get_infinidat_filesystem_by_name(self, name):
@@ -310,12 +337,14 @@ class InfiniboxShareDriver(driver.ShareDriver):
     @infinisdk_to_manila_exceptions
     def _create_filesystem_export(self, infinidat_filesystem):
         infinidat_export = infinidat_filesystem.add_export(permissions=[])
-        return {
-            'path': self._get_full_nfs_export_path(
-                infinidat_export.get_export_path()),
+        export_paths = self._get_full_nfs_export_paths(
+            infinidat_export.get_export_path())
+        export_locations = [{
+            'path': export_path,
             'is_admin_only': False,
             'metadata': {},
-        }
+        } for export_path in export_paths]
+        return export_locations
 
     @infinisdk_to_manila_exceptions
     def _delete_share(self, share, is_snapshot):
@@ -341,7 +370,9 @@ class InfiniboxShareDriver(driver.ShareDriver):
 
     @infinisdk_to_manila_exceptions
     def _extend_share(self, infinidat_filesystem, share, new_size):
+        # pylint: disable=no-member
         new_size_capacity_units = new_size * capacity.GiB
+        # pylint: enable=no-member
         old_size = infinidat_filesystem.get_size()
         infinidat_filesystem.resize(new_size_capacity_units - old_size)
 
@@ -362,7 +393,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
         self._verify_share_protocol(share)
 
         pool = self._get_infinidat_pool()
-        size = share['size'] * capacity.GiB
+        size = share['size'] * capacity.GiB    # pylint: disable=no-member
         share_name = self._make_share_name(share)
 
         infinidat_filesystem = self._system.filesystems.create(
@@ -375,7 +406,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
                                    share_server=None):
         name = self._make_share_name(share)
         infinidat_snapshot = self._get_infinidat_snapshot(snapshot)
-        infinidat_new_share = infinidat_snapshot.create_child(
+        infinidat_new_share = infinidat_snapshot.create_snapshot(
             name=name, write_protected=False)
         self._extend_share(infinidat_new_share, share, share['size'])
         return self._create_filesystem_export(infinidat_new_share)
@@ -386,12 +417,12 @@ class InfiniboxShareDriver(driver.ShareDriver):
         share = snapshot['share']
         infinidat_filesystem = self._get_infinidat_filesystem(share)
         name = self._make_snapshot_name(snapshot)
-        infinidat_snapshot = infinidat_filesystem.create_child(name=name)
+        infinidat_snapshot = infinidat_filesystem.create_snapshot(name=name)
         # snapshot is created in the same size as the original share, so no
         # extending is needed
         self._set_manila_object_metadata(infinidat_snapshot, snapshot)
         return {'export_locations':
-                [self._create_filesystem_export(infinidat_snapshot)]}
+                self._create_filesystem_export(infinidat_snapshot)}
 
     def delete_share(self, context, share, share_server=None):
         try:
@@ -413,16 +444,14 @@ class InfiniboxShareDriver(driver.ShareDriver):
         infinidat_filesystem = self._get_infinidat_filesystem(share)
         try:
             infinidat_export = self._get_export(infinidat_filesystem)
+            return self._get_full_nfs_export_paths(
+                infinidat_export.get_export_path())
         except exception.ShareBackendException:
             # export not found, need to re-export
             message = ("missing export for share %(share)s, trying to "
                        "re-export")
             LOG.info(message, {"share": share})
-            infinidat_export = (
-                self._create_filesystem_export(infinidat_filesystem))
-            return [self._get_full_nfs_export_path(infinidat_export['path'])]
-        return [self._get_full_nfs_export_path(
-            infinidat_export.get_export_path())]
+            return self._create_filesystem_export(infinidat_filesystem)
 
     def update_access(self, context, share, access_rules, add_rules,
                       delete_rules, share_server=None):
