@@ -71,9 +71,6 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
     def shrink_share(self, share, new_size, **kwargs):
         self.library.shrink_share(share, new_size, **kwargs)
 
-    def ensure_share(self, context, share, **kwargs):
-        pass
-
     def manage_existing(self, share, driver_options):
         raise NotImplementedError
 
@@ -86,6 +83,22 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
     def unmanage_snapshot(self, snapshot):
         raise NotImplementedError
 
+    def manage_existing_with_server(
+            self, share, driver_options, share_server=None):
+        return self.library.manage_existing(
+            share, driver_options, share_server=share_server)
+
+    def unmanage_with_server(self, share, share_server=None):
+        self.library.unmanage(share, share_server=share_server)
+
+    def manage_existing_snapshot_with_server(
+            self, snapshot, driver_options, share_server=None):
+        return self.library.manage_existing_snapshot(
+            snapshot, driver_options, share_server=share_server)
+
+    def unmanage_snapshot_with_server(self, snapshot, share_server=None):
+        self.library.unmanage_snapshot(snapshot, share_server=share_server)
+
     def update_access(self, context, share, access_rules, add_rules,
                       delete_rules, **kwargs):
         self.library.update_access(context, share, access_rules, add_rules,
@@ -120,42 +133,57 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
     def _teardown_server(self, server_details, **kwargs):
         self.library.teardown_server(server_details, **kwargs)
 
-    def create_replica(self, context, replica_list, replica, access_rules,
+    def create_replica(self, context, replica_list, new_replica, access_rules,
                        replica_snapshots, **kwargs):
-        raise NotImplementedError()
+        return self.library.create_replica(context, replica_list, new_replica,
+                                           access_rules, replica_snapshots)
 
     def delete_replica(self, context, replica_list, replica_snapshots,
                        replica, **kwargs):
-        raise NotImplementedError()
+        self.library.delete_replica(context, replica_list, replica,
+                                    replica_snapshots)
 
     def promote_replica(self, context, replica_list, replica, access_rules,
                         share_server=None):
-        raise NotImplementedError()
+        return self.library.promote_replica(context, replica_list, replica,
+                                            access_rules,
+                                            share_server=share_server)
 
     def update_replica_state(self, context, replica_list, replica,
                              access_rules, replica_snapshots,
                              share_server=None):
-        raise NotImplementedError()
+        return self.library.update_replica_state(context, replica_list,
+                                                 replica, access_rules,
+                                                 replica_snapshots,
+                                                 share_server)
 
     def create_replicated_snapshot(self, context, replica_list,
                                    replica_snapshots, share_server=None):
-        raise NotImplementedError()
+        return self.library.create_replicated_snapshot(
+            context, replica_list, replica_snapshots,
+            share_server=share_server)
 
     def delete_replicated_snapshot(self, context, replica_list,
                                    replica_snapshots, share_server=None):
-        raise NotImplementedError()
+        return self.library.delete_replicated_snapshot(
+            context, replica_list, replica_snapshots,
+            share_server=share_server)
 
     def update_replicated_snapshot(self, context, replica_list,
                                    share_replica, replica_snapshots,
                                    replica_snapshot, share_server=None):
-        raise NotImplementedError()
+        return self.library.update_replicated_snapshot(
+            replica_list, share_replica, replica_snapshots, replica_snapshot,
+            share_server=share_server)
 
     def revert_to_replicated_snapshot(self, context, active_replica,
                                       replica_list, active_replica_snapshot,
                                       replica_snapshots, share_access_rules,
                                       snapshot_access_rules,
-                                      share_server=None):
-        raise NotImplementedError()
+                                      **kwargs):
+        return self.library.revert_to_replicated_snapshot(
+            context, active_replica, replica_list, active_replica_snapshot,
+            replica_snapshots, **kwargs)
 
     def migration_check_compatibility(self, context, source_share,
                                       destination_share, share_server=None,
@@ -237,3 +265,21 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
 
     def get_configured_ip_versions(self):
         return self.library.get_configured_ip_versions()
+
+    def get_backend_info(self, context):
+        return self.library.get_backend_info(context)
+
+    def ensure_shares(self, context, shares):
+        return self.library.ensure_shares(context, shares)
+
+    def get_share_server_network_info(
+            self, context, share_server, identifier, driver_options):
+        return self.library.get_share_server_network_info(
+            context, share_server, identifier, driver_options)
+
+    def manage_server(self, context, share_server, identifier, driver_options):
+        return self.library.manage_server(
+            context, share_server, identifier, driver_options)
+
+    def unmanage_server(self, server_details, security_services=None):
+        return self.library.unmanage_server(server_details, security_services)
