@@ -71,7 +71,9 @@ netapp_provisioning_opts = [
                default='share_%(share_id)s'),
     cfg.StrOpt('netapp_vserver_name_template',
                default='os_%s',
-               help='Name template to use for new Vserver.'),
+               help='Name template to use for new Vserver. '
+                    'When using CIFS protocol make sure to not '
+                    'configure characters illegal in DNS hostnames.'),
     cfg.StrOpt('netapp_qos_policy_group_name_template',
                help='NetApp QoS policy group name template.',
                default='qos_share_%(share_id)s'),
