@@ -414,7 +414,11 @@ class ServiceInstanceManager(object):
         t = time.time()
         while time.time() - t < self.max_time_to_build_instance:
             try:
-                self.compute_api.server_get(context, server_id)
+                inst = self.compute_api.server_get(context, server_id)
+                if inst.get("status").lower() == "soft_deleted":
+                    LOG.debug("Service instance '%s' was soft-deleted "
+                              "successfully.", server_id)
+                    break
             except exception.InstanceNotFound:
                 LOG.debug("Service instance '%s' was deleted "
                           "successfully.", server_id)
@@ -833,8 +837,7 @@ class NeutronNetworkHelper(BaseNetworkhelper):
 
         if router_id and subnet_id:
             ports = self.neutron_api.list_ports(
-                fields=['device_id', 'device_owner'],
-                fixed_ips=['subnet_id=%s' % subnet_id])
+                fields=['fixed_ips', 'device_id', 'device_owner'])
             # NOTE(vponomaryov): iterate ports to get to know whether current
             # subnet is used or not. We will not remove it from router if it
             # is used.
@@ -844,10 +847,12 @@ class NeutronNetworkHelper(BaseNetworkhelper):
                 # we know that it is VM. We continue only if both are 'True'.
                 if (port['device_id'] and
                         port['device_owner'].startswith('compute:')):
-                    # NOTE(vponomaryov): There are other share servers
-                    # exist that use this subnet. So, do not remove it
-                    # from router.
-                    return
+                    for fixed_ip in port['fixed_ips']:
+                        if fixed_ip['subnet_id'] == subnet_id:
+                            # NOTE(vponomaryov): There are other share servers
+                            # exist that use this subnet. So, do not remove it
+                            # from router.
+                            return
             try:
                 # NOTE(vponomaryov): there is no other share servers or
                 # some VMs that use this subnet. So, remove it from router.
