@@ -36,7 +36,7 @@ class ShareInstancesAPITest(test.TestCase):
     """Share instances API Test."""
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareInstancesAPITest, self).setUp()
         self.controller = share_instances.ShareInstancesController()
         self.resource_name = self.controller.resource_name
         self.mock_policy_check = self.mock_object(
@@ -51,9 +51,8 @@ class ShareInstancesAPITest(test.TestCase):
         if instance is None:
             instance = db_utils.create_share(status=constants.STATUS_AVAILABLE,
                                              size='1').instance
-        req = fakes.HTTPRequest.blank(
-            '/v2/fake/share_instances/%s/action' % instance['id'],
-            version=version)
+        path = '/v2/fake/share_instances/%s/action' % instance['id']
+        req = fakes.HTTPRequest.blank(path, script_name=path, version=version)
         return instance, req
 
     def _get_request(self, uri, context=None, version="2.3"):
@@ -249,14 +248,8 @@ class ShareInstancesAPITest(test.TestCase):
         # validate response code and model status
         self.assertEqual(valid_code, resp.status_int)
 
-        if valid_code == 404:
-            self.assertRaises(exception.NotFound,
-                              db_access_method,
-                              ctxt,
-                              model['id'])
-        else:
-            actual_model = db_access_method(ctxt, model['id'])
-            self.assertEqual(valid_status, actual_model['status'])
+        actual_model = db_access_method(ctxt, model['id'])
+        self.assertEqual(valid_status, actual_model['status'])
 
     @ddt.data(*fakes.fixture_reset_status_with_different_roles)
     @ddt.unpack
