@@ -179,6 +179,23 @@ class TestClient(test.TestCase):
 
         self.assertEqual(5 * units.Gi, size)
 
+    @res_mock.mock_client_input
+    @res_mock.patch_client
+    def test_shrink_filesystem(self, client, mocked_input):
+        fs = mocked_input['fs']
+
+        size = client.shrink_filesystem('fake_share_id_1', fs, 4)
+
+        self.assertEqual(4 * units.Gi, size)
+
+    @res_mock.mock_client_input
+    @res_mock.patch_client
+    def test_shrink_filesystem_size_too_small(self, client, mocked_input):
+        fs = mocked_input['fs']
+
+        self.assertRaises(exception.ShareShrinkingPossibleDataLoss,
+                          client.shrink_filesystem, 'fake_share_id_2', fs, 4)
+
     @res_mock.patch_client
     def test_get_file_ports(self, client):
         ports = client.get_file_ports()
@@ -231,3 +248,15 @@ class TestClient(test.TestCase):
             v6_prefix_length=mock_file_interface.prefix_length,
             gateway=mock_file_interface.gateway,
             vlan_id=mock_file_interface.vlan_id)
+
+    @res_mock.patch_client
+    def test_get_snapshot(self, client):
+        snapshot = client.get_snapshot('Snapshot_1')
+        self.assertEqual('snapshot_1', snapshot.id)
+
+    @res_mock.patch_client
+    def test_restore_snapshot(self, client):
+        snapshot = client.get_snapshot('Snapshot_1')
+        rst = client.restore_snapshot(snapshot.name)
+        self.assertIs(True, rst)
+        snapshot.restore.assert_called_once_with(delete_backup=True)
